@@ -36,6 +36,7 @@ LANGUAGES = {u'ach': {u'English': u'Acholi', u'native': u'Acholi'},
             u'native': u'Deutsch (Deutschland)'},
  u'dsb': {u'English': u'Lower Sorbian',
           u'native': u'Dolnoserb\u0161\u0107ina'},
+ u'ee': {u'English': u'Ewe', u'native': u'\xc8\u028begbe'},
  u'el': {u'English': u'Greek',
          u'native': u'\u0395\u03bb\u03bb\u03b7\u03bd\u03b9\u03ba\u03ac'},
  u'en-AU': {u'English': u'English (Australian)',
@@ -100,6 +101,7 @@ LANGUAGES = {u'ach': {u'English': u'Acholi', u'native': u'Acholi'},
  u'la': {u'English': u'Latin', u'native': u'Latina'},
  u'lg': {u'English': u'Luganda', u'native': u'Luganda'},
  u'lij': {u'English': u'Ligurian', u'native': u'Ligure'},
+ u'ln': {u'English': u'Lingala', u'native': u'Ling\xe1la'},
  u'lo': {u'English': u'Lao',
          u'native': u'\u0e9e\u0eb2\u0eaa\u0eb2\u0ea5\u0eb2\u0ea7'},
  u'lt': {u'English': u'Lithuanian', u'native': u'lietuvi\u0173 kalba'},
