@@ -13,7 +13,7 @@ REGIONS = {u'ad': u'\u0d06\u0d28\u0d4d\u200d\u0d21\u0d4b\u0d31\u0d3e',
  u'at': u'\u0d13\u0d38\u0d4d\u0d1f\u0d4d\u0d30\u0d3f\u0d2f',
  u'au': u'\u0d13\u0d38\u0d4d\u0d1f\u0d4d\u0d30\u0d47\u0d32\u0d3f\u0d2f\u0d3e',
  u'aw': u'\u0d05\u0d30\u0d41\u0d2c\u0d3e',
- u'ax': u'\\u00c5land \u0d26\u0d4d\u0d35\u0d40\u0d2a\u0d41\u0d15\u0d33\u0d4d\u200d',
+ u'ax': u'\xc5land \u0d26\u0d4d\u0d35\u0d40\u0d2a\u0d41\u0d15\u0d33\u0d4d\u200d',
  u'az': u'\u0d05\u0d38\u0d30\u0d4d\u200d\u0d2c\u0d48\u0d1c\u0d28\u0d4d\u200d',
  u'ba': u'\u0d2c\u0d4b\u0d38\u0d4d\u0d28\u0d3f\u0d2f\u0d3e \u0d06\u0d28\u0d4d\u200d\u0d21\u0d4d \u0d39\u0d46\u0d30\u0d4d\u200d\u0d38\u0d46\u0d17\u0d4b\u0d35\u0d3e\u0d28\u0d3f\u0d2f\u0d3e',
  u'bb': u'\u0d2c\u0d30\u0d4d\u200d\u0d2c\u0d3e\u0d21\u0d4b\u0d38\u0d4d',
