@@ -13,7 +13,7 @@ REGIONS = {u'ad': u'\u0b06\u0b28\u0b21\u0b4b\u0b30\u0b3e',
  u'at': u'\u0b05\u0b37\u0b4d\u0b1f\u0b4d\u0b30\u0b3f\u0b06',
  u'au': u'\u0b05\u0b37\u0b4d\u0b1f\u0b4d\u0b30\u0b47\u0b32\u0b3f\u0b06',
  u'aw': u'\u0b06\u0b30\u0b41\u0b2c\u0b3e',
- u'ax': u'\\u00c5land \u0b06\u0b07\u0b32\u0b4d\u0b5f\u0b3e\u0b23\u0b4d\u0b21',
+ u'ax': u'\xc5land \u0b06\u0b07\u0b32\u0b4d\u0b5f\u0b3e\u0b23\u0b4d\u0b21',
  u'az': u'\u0b06\u0b1c\u0b3e\u0b30\u0b2c\u0b3e\u0b07\u0b1c\u0b3e\u0b28',
  u'ba': u'\u0b2c\u0b4b\u0b38\u0b28\u0b3f\u0b06 \u0b0f\u0b2c\u0b02 \u0b39\u0b3e\u0b30\u0b4d\u0b1c\u0b47\u0b17\u0b4b\u0b2d\u0b3f\u0b28\u0b3e',
  u'bb': u'\u0b2c\u0b3e\u0b30\u0b4d\u0b2c\u0b3e\u0b21\u0b4b\u0b38',
@@ -24,7 +24,7 @@ REGIONS = {u'ad': u'\u0b06\u0b28\u0b21\u0b4b\u0b30\u0b3e',
  u'bh': u'\u0b2c\u0b3e\u0b39\u0b3e\u0b30\u0b3e\u0b28',
  u'bi': u'\u0b2c\u0b41\u0b30\u0b41\u0b23\u0b4d\u0b21\u0b3f',
  u'bj': u'\u0b2c\u0b47\u0b28\u0b3f\u0b28',
- u'bl': u'Saint Barth\\u00e9lemy',
+ u'bl': u'Saint Barth\xe9lemy',
  u'bm': u'\u0b2c\u0b30\u0b2e\u0b41\u0b21\u0b3c\u0b3e',
  u'bn': u'\u0b2c\u0b4d\u0b30\u0b41\u0b28\u0b47\u0b07 \u0b1c\u0b47\u0b30\u0b41\u0b1c\u0b47\u0b32\u0b2e',
  u'bo': u'\u0b2c\u0b32\u0b3f\u0b2d\u0b3f\u0b06',
